rm(list=ls())# wipes slate clean
library(mgcv)
library(lme4)
library(lmerTest)
library(ggplot2)
library(dplyr)
library( geosphere )
library( stringr)
setwd("C:/Users/Ragenaky/Desktop/Thesis chapter 3/Data/Master Sheets")

#Calculate a standard error
stderr <- function(x, ...) sd(x, na.rm = TRUE) / sqrt(length(is.na(x == FALSE)) )


### Install this When you start for Multiplots!!!#####
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}


#Fig 3a

MST_IC_ASD_IMP_WD<-read.csv("MST_IC_ASD_IMP_WD.CSV")

MST_IC_ASD_IMP_WD$logC=log(MST_IC_ASD_IMP_WD[,18]+1)
MST_IC_ASD_IMP_WD$logT=log(MST_IC_ASD_IMP_WD[,21]+1)

LM1 <- lm(logC ~  
             logT,                                                 
           data=MST_IC_ASD_IMP_WD,)
anova(LM1)
summary(LM1)

coeffs <- data.frame( summary(LM1)$coefficients )

coeffs$names <- str_remove( rownames(coeffs), "MST_IC_ASD_IMP_WD" )



fig3a <- ggplot(coeffs, aes(x =  names,Estimate, y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mono Crop / Intercrop", y = "Weed Density Coefficient") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.65))

fig3a

MST_IC_ASD_IMP_YD<-read.csv("MST_IC_ASD_IMP_YD.CSV")

MST_IC_ASD_IMP_YD$logC=log(MST_IC_ASD_IMP_YD[,18]+1)
MST_IC_ASD_IMP_YD$logT=log(MST_IC_ASD_IMP_YD[,21]+1)

LM2 <- lm(logC ~  
             logT,                                                 
           data=MST_IC_ASD_IMP_YD,)
anova(LM2)
summary(LM2)


coeffs <- data.frame( summary(LM2)$coefficients )

coeffs$names <- str_remove( rownames(coeffs), "MST_IC_ASD_IMP_YD" )



fig3b <- ggplot(coeffs, aes(x =  names, Estimate, y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mono Crop / Intercrop", y = "Crop Yield Coefficient") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.65))

fig3b

MST_RC_ASD_IMP_WD<-read.csv("MST_RC_ASD_IMP_WD.CSV")

MST_RC_ASD_IMP_WD$logC=log(MST_RC_ASD_IMP_WD[,25]+1)
MST_RC_ASD_IMP_WD$logT=log(MST_RC_ASD_IMP_WD[,28]+1)

LM3 <- lm(logC ~  
            logT,                                                 
           data=MST_RC_ASD_IMP_WD,)
anova(LM3)
summary(LM3)

coeffs <- data.frame( summary(LM3)$coefficients )

coeffs$names <- str_remove( rownames(coeffs), "MST_RC_ASD_IMP_WD" )



fig3c <- ggplot(coeffs, aes(x =  names, Estimate, y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mono Crop / Rotation Crop", y = "Weed Density Coefficient") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.65))

fig3c

MST_RC_ASD_IMP_YD<-read.csv("MST_RC_ASD_IMP_YD.CSV")

MST_RC_ASD_IMP_YD$logC=log(MST_RC_ASD_IMP_YD[,25]+1)
MST_RC_ASD_IMP_YD$logT=log(MST_RC_ASD_IMP_YD[,28]+1)

LM4 <- lm(logC ~  
            logT,                                                 
           data=MST_RC_ASD_IMP_YD,)
anova(LM4)
summary(LM4)

coeffs <- data.frame( summary(LM4)$coefficients )

coeffs$names <- str_remove( rownames(coeffs), "MST_RC_ASD_IMP_YD" )



fig3d <- ggplot(coeffs, aes(x =  names, Estimate, y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mono Crop / Rotation Crop", y = "Crop Yield Coefficient") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.65))

fig3d

multiplot(fig3a + labs( tag = "A"), fig3b + labs( tag = "B"), fig3c + labs( tag = "C"), fig3d + labs( tag = "D"), cols = 2)
