rm(list=ls())# wipes slate clean
library(dplyr)
library(ggplot2)
library(coin)
library(MASS)
library(foreign)
library(Hmisc)
library(reshape2)
library(mgcv)
library(lme4)
library(lmerTest)
library(gridExtra)
library(meta)
library(esc)
library(effsize)
library( geosphere )
library( stringr)
library(plotrix)

#Calculate a standard error
stderr <- function(x, ...) sd(x, na.rm = TRUE) / sqrt(length(is.na(x == FALSE)) )

### Install this When you start for Multiplots!!!#####
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

setwd("C:/Users/Ragenaky/Desktop/Thesis chapter 3/Data/Master Sheets/Sheets with small records removed for fig 4")

# Read in the data
MST_IC_ASD_IMP_WD<-read.csv("MST_IC_ASD_IMP_WD_MINC_REM.CSV")

#mixed.mod1 <- lmer(HEDGES ~  # this is the individual effect size as the response variable
                     #IC_SP+   # this is the fixed effects - so you could add the grouping variable here and it will tell you whether there is a difference in 
                     ## effect size between different levels of the variable
                     #(1|Study_ID) ,                                                 # this is the random effects (in this case grouping multiple effect sizes in each study together)
                   #data=MST_IC_ASD_IMP_WD,
                  # weights = 1/VAR_G,                                          # this is the weighting variable required for a meta-analysis (var.g = the individual effect size variances)
                   #na.action = "na.omit")
#anova(mixed.mod1)
#summary(mixed.mod1)

#coeffs <- data.frame( summary(mixed.mod1)$coefficients )

#coeffs$names <- str_remove( rownames(coeffs), "MST_RC_ASD_IMP_WD" )
MST_IC_ASD_IMP_WD <- MST_IC_ASD_IMP_WD %>% 
  group_by(IC_SP) %>% 
  summarise(mean = mean(HEDGES),
            stde = stderr(HEDGES))

Figure4a <- ggplot(MST_IC_ASD_IMP_WD, aes(x = reorder( IC_SP, mean), y = mean) ) +	
  geom_point( size = 1) +
  geom_errorbar(aes( ymin = mean -stde, ymax = mean + stde ), width = 0.5, size = 0.25 ) +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         legend.position="none",
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.text.x = element_text(angle = 30, vjust = .55, hjust=.40,size = 10),
         axis.text.y = element_text(size = 8),
         axis.title.x=element_text(size = 12),
         axis.title.y=element_text(size = 12) ) +
  geom_hline(yintercept = 0, linetype  = "dashed") +
  labs(x = "Intercrop") + labs( y = "Effect Size (g)", las=2)
  

  Figure4a
  
 
  MST_RC_ASD_IMP_WD<-read.csv("MST_RC_ASD_IMP_WD_MINC_REM.CSV") 
  
  MST_RC_ASD_IMP_WD <- MST_RC_ASD_IMP_WD %>% 
    group_by(RC_1_SP) %>% 
    summarise(mean = mean(HEDGES),
              stde = stderr(HEDGES))
  
  Figure4b <- ggplot(MST_RC_ASD_IMP_WD, aes(x = reorder( RC_1_SP, mean), y = mean) ) +	
    geom_point( size = 1) +
    geom_errorbar(aes( ymin = mean -stde, ymax = mean + stde ), width = 0.5, size = 0.25 ) +
    theme_bw() + 
    theme( panel.border = element_blank(), 
           panel.grid.major = element_blank(),
           panel.grid.minor = element_blank(), 
           legend.position="none",
           axis.line = element_line(colour = 'black', size = 0.25),
           axis.ticks = element_line(colour = "black", size = 0.25),
           axis.text.x = element_text(angle = 40, vjust = .55, hjust=.40,size = 10),
           axis.text.y = element_text(size = 8),
           axis.title.x=element_text(size = 12),
           axis.title.y=element_text(size = 12) ) +
    geom_hline(yintercept = 0, linetype  = "dashed") +
    labs(x = "Rotation Crop") + labs( y = "Effect Size (g)", las=2)
  
  
  Figure4b
  
  multiplot(Figure4a + labs( tag = "A"), Figure4b+ labs( tag = "B"), cols = 1)