rm(list=ls())# wipes slate clean
library(mgcv)
library(lme4)
library(lmerTest)
library(ggplot2)
library(dplyr)
library( geosphere )
library( stringr)
setwd("C:/Users/Ragenaky/Desktop/Thesis chapter 3/Data/Master Sheets")

### Install this When you start for Multiplots!!!#####
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

MST_RC_ASD_IMP_WD<-read.csv("MST_RC_ASD_IMP_WD.CSV")

stderr <- function(x) sd(x) / sqrt(length(x))

MST_RC_ASD_IMP_WD$DIV <- as.factor(MST_RC_ASD_IMP_WD$DIV)#To change DIV to 4 level factor

#Divide treatment by control to make weed density % difference
MST_RC_ASD_IMP_WD$WDDif<- (MST_RC_ASD_IMP_WD$Treat_Mean/MST_RC_ASD_IMP_WD$Control_Mean)*100

#Look at diversity and change in weed density
LM1 <- lm( WDDif  ~  DIV, data=MST_RC_ASD_IMP_WD)
anova(LM1)         
           
summary(LM1)

coeffs <- data.frame( summary(LM1)$coefficients )

coeffs$names <- str_remove( rownames(coeffs), "MST_RC_ASD_IMP_WD" )

RCD<- c("1", "2", "3","4")#For the x tick labels

fig5a <- ggplot(coeffs, aes(x =  names,Estimate, y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.2, size = 0.25 ) +
  theme_bw() +  scale_x_discrete(labels= RCD)+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Rotation Crop Diversity", y = "Density Change Coefficient") + 
  theme(axis.text.x = element_text(angle = 0, vjust = .7, hjust=.65))
fig5a

fig5b<-ggplot(data = MST_RC_ASD_IMP_WD, aes(x=DIV, y=WDDif)) +
  geom_boxplot(fill=c('red', 'Yellow', 'blue','green'))+
  labs( x = "Rotation Crop Diversity", y = "Weed Density Change")


fig5b

#Redo the LMER with diversity as a factor using effect size

mixed.mod1 <- lmer(HEDGES ~  
                      DIV + 
                      (1|Study_ID) ,                                                 
                    data=MST_RC_ASD_IMP_WD,
                    weights = 1/VAR_G,                                        
                    na.action = "na.omit")
anova(mixed.mod1)
summary(mixed.mod1)

coeffs <- data.frame( summary(mixed.mod1)$coefficients )

coeffs$names <- str_remove( rownames(coeffs), "MST_RC_ASD_IMP_WD" )

fig5c <- ggplot(coeffs, aes(x =  names,Estimate, y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.2, size = 0.25 ) +
  theme_bw() +  scale_x_discrete(labels= RCD)+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Rotation Crop Diversity", y = "Effect Size (g)") + 
  theme(axis.text.x = element_text(angle = 0, vjust = .7, hjust=.65))

fig5c

fig5d<-ggplot(data = MST_RC_ASD_IMP_WD, aes(x=DIV, y=HEDGES)) +
  geom_boxplot(fill=c('grey', 'grey', 'grey','grey'))+
  labs( x = "Rotation Crop Diversity", y = "Effect Size (g)")


fig5d



Figure5e <- ggplot( MST_RC_ASD_IMP_WD, aes(x = DIV, y = HEDGES) ) +	
  geom_point( size = 1) +
  geom_errorbar( aes(ymin = HEDGES - VAR_G, ymax = HEDGES + VAR_G, width = 0.1,  ))  +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         legend.position="none",
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.text.x = element_text(size = 10),
         axis.text.y = element_text(size = 8),
         axis.title.x=element_text(size = 14),
         axis.title.y=element_text(size = 14) ) +
  geom_hline(yintercept = 0, linetype  = "dashed") +
  labs(x = "Rotation Crop Diversity") + labs( y = "Effect Size (g)", las=2)

Figure5e

multiplot(fig5a + labs( tag = "A"), fig5c+ labs( tag = "B"),  cols = 1)
